@@ -175,6 +175,8 @@ void SessionThread::slotDataReceived()
         if (m_pendingQuantity <= 0) {
             qCDebug(KMANAGERSIEVE_LOG) << "S: " << m_data.trimmed();
             Q_EMIT responseReceived(m_lastResponse, m_data);
+        } else {
+            return; // waiting for more data
         }
     }
 
@@ -195,7 +197,7 @@ void SessionThread::slotDataReceived()
         qCDebug(KMANAGERSIEVE_LOG) << r.type() << r.key() << r.value() << r.extra() << r.quantity();
 
         m_lastResponse = r;
-        if (r.type() == Response::Quantity) {
+        if (r.quantity() > 0) {
             m_data.clear();
             m_pendingQuantity = r.quantity();
             slotDataReceived(); // in case the data block is already completely in the buffer
@@ -206,7 +208,6 @@ void SessionThread::slotDataReceived()
         }
         Q_EMIT responseReceived(r, QByteArray());
     }
-    m_pendingQuantity = 0;
 }
 
 // Called in secondary thread
@@ -214,37 +215,10 @@ void SessionThread::slotSocketError()
 {
     Q_ASSERT(QThread::currentThread() == thread());
 
-    qCDebug(KMANAGERSIEVE_LOG) << Q_FUNC_INFO << m_socket->errorString();
+    qCWarning(KMANAGERSIEVE_LOG) << Q_FUNC_INFO << m_socket->errorString();
     doDisconnectFromHost(false);
 }
 
-// Called in main thread
-void SessionThread::feedBack(const QByteArray &data)
-{
-    QMetaObject::invokeMethod(this, "doFeedBack",
-                              Qt::QueuedConnection,
-                              Q_ARG(QByteArray, data));
-}
-
-// Called in secondary thread
-void SessionThread::doFeedBack(const QByteArray &data)
-{
-    Q_ASSERT(QThread::currentThread() == thread());
-
-    Response response;
-    response.parseResponse(data);
-    m_lastResponse = response;
-
-    if (response.type() == Response::Quantity) {
-        m_data.clear();
-        m_pendingQuantity = response.quantity();
-        slotDataReceived();
-        return;
-    } else {
-        Q_EMIT responseReceived(response, QByteArray());
-    }
-}
-
 // Called in main thread
 void SessionThread::startAuthentication()
 {
@@ -496,24 +470,3 @@ void SessionThread::sslResult(bool encrypted)
         Q_EMIT sslDone();
     }
 }
-
-// Called in main thread
-void SessionThread::handleSslErrorResponse(bool response)
-{
-    QMetaObject::invokeMethod(this, "doHandleSslErrorResponse",
-                              Qt::QueuedConnection,
-                              Q_ARG(bool, response));
-}
-
-// Called in secondary thread
-void SessionThread::doHandleSslErrorResponse(bool response)
-{
-    Q_ASSERT(QThread::currentThread() == thread());
-
-    if (!response) {
-        doDisconnectFromHost(true);
-        return;
-    }
-
-    Q_EMIT sslDone();
-}
