@@ -1,26 +1,28 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
-
 #include "sieveeditortabwidget.h"
 #include "ksieveui/editor/sieveeditorhelphtmlwidget.h"
 
 #include <KLocalizedString>
 #include <KStringHandler>
 
+#include <QMenu>
 #include <QTabBar>
 #include <QUrl>
 
@@ -30,6 +32,8 @@ SieveEditorTabWidget::SieveEditorTabWidget(QWidget *parent)
 {
     setTabsClosable(true);
     connect(this, &SieveEditorTabWidget::tabCloseRequested, this, &SieveEditorTabWidget::slotTabCloseRequested);
+    setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(this, &SieveEditorTabWidget::customContextMenuRequested, this, &SieveEditorTabWidget::slotTabContextMenuRequest);
 }
 
 SieveEditorTabWidget::~SieveEditorTabWidget()
@@ -37,6 +41,72 @@ SieveEditorTabWidget::~SieveEditorTabWidget()
 
 }
 
+void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
+{
+    QTabBar *bar = tabBar();
+    if (count() <= 1) {
+        return;
+    }
+
+    const int indexBar = bar->tabAt(bar->mapFrom(this, pos));
+    if (indexBar == -1) {
+        return;
+    }
+    QMenu menu(this);
+
+    const int countTab = (count() > 1);
+
+    QAction *closeTab = menu.addAction(i18nc("@action:inmenu", "Close Tab"));
+    closeTab->setEnabled((indexBar != 0) && countTab);
+    closeTab->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
+
+    QAction *allOther = menu.addAction(i18nc("@action:inmenu", "Close All Other Tabs"));
+    allOther->setEnabled(countTab);
+    allOther->setIcon(QIcon::fromTheme(QStringLiteral("tab-close-other")));
+
+    QAction *allTab = menu.addAction(i18nc("@action:inmenu", "Close All Tabs"));
+    allTab->setEnabled(countTab);
+    allTab->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
+
+    QAction *action = menu.exec(mapToGlobal(pos));
+
+    if (action == allOther) {   // Close all other tabs
+        slotCloseAllTabExcept(indexBar);
+    } else if (action == closeTab) {
+        slotCloseRequest(indexBar);
+    } else if (action == allTab) {
+        slotCloseAllTab();
+    }
+}
+
+void SieveEditorTabWidget::slotCloseRequest(int index)
+{
+    if (index != 0) {
+        removeTab(index);
+    }
+}
+
+void SieveEditorTabWidget::closeAllTabExcept(int index)
+{
+    //Don't close first tab
+    for (int i = count() - 1; i > 0; --i) {
+        if (i == index) {
+            continue;
+        }
+        removeTab(i);
+    }
+}
+
+void SieveEditorTabWidget::slotCloseAllTabExcept(int index)
+{
+    closeAllTabExcept(index);
+}
+
+void SieveEditorTabWidget::slotCloseAllTab()
+{
+    closeAllTabExcept();
+}
+
 void SieveEditorTabWidget::slotTabCloseRequested(int index)
 {
     //Don't remove first tab.
@@ -76,6 +146,7 @@ void SieveEditorTabWidget::slotAddHelpPage(const QUrl &url)
     connect(htmlPage, &SieveEditorHelpHtmlWidget::titleChanged, this, &SieveEditorTabWidget::slotTitleChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::progressIndicatorPixmapChanged, this, &SieveEditorTabWidget::slotProgressIndicatorPixmapChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::loadFinished, this, &SieveEditorTabWidget::slotLoadFinished);
+    connect(htmlPage, &SieveEditorHelpHtmlWidget::copyAvailable, this, &SieveEditorTabWidget::copyAvailable);
     htmlPage->openUrl(url);
     const int index = addTab(htmlPage, i18n("Help"));
     setCurrentIndex(index);
