@@ -50,7 +50,9 @@
 #include <QPointer>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <QDebug>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <PimCommon/KPimPrintPreviewDialog>
 
 #include <errno.h>
 
@@ -85,13 +87,21 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     QVBoxLayout *textEditLayout = new QVBoxLayout;
     textEditLayout->setMargin(0);
 
+    mEditorWidget = new QWidget;
+    QVBoxLayout *editorWidgetLayout = new QVBoxLayout;
+    editorWidgetLayout->setMargin(0);
+    mEditorWidget->setLayout(editorWidgetLayout);
+
     mTabWidget = new SieveEditorTabWidget;
+    connect(mTabWidget, &SieveEditorTabWidget::currentChanged, this, &SieveEditorTextModeWidget::sieveEditorTabCurrentChanged);
+    connect(mTabWidget, &SieveEditorTabWidget::copyAvailable, this, &SieveEditorTextModeWidget::copyAvailable);
     mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
-    textEditLayout->addWidget(mTextToSpeechWidget);
+    editorWidgetLayout->addWidget(mTextToSpeechWidget);
 
     mTextEdit = new SieveTextEdit;
+    editorWidgetLayout->addWidget(mTextEdit);
     connect(mTextEdit, &SieveTextEdit::textChanged, this, &SieveEditorTextModeWidget::valueChanged);
-    mTabWidget->addTab(mTextEdit, i18n("Editor"));
+    mTabWidget->addTab(mEditorWidget, i18n("Editor"));
     mTabWidget->tabBar()->hide();
     textEditLayout->addWidget(mTabWidget);
     connect(mTextEdit, &SieveTextEdit::openHelp, mTabWidget, &SieveEditorTabWidget::slotAddHelpPage);
@@ -101,7 +111,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mGoToLine = new KPIMTextEdit::TextGoToLineWidget;
     mGoToLine->hide();
     mGotoLineSliderContainer->setContent(mGoToLine);
-    textEditLayout->addWidget(mGotoLineSliderContainer);
+    editorWidgetLayout->addWidget(mGotoLineSliderContainer);
     connect(mGoToLine, &KPIMTextEdit::TextGoToLineWidget::hideGotoLine, mGotoLineSliderContainer, &KPIMTextEdit::SlideContainer::slideOut);
 
     connect(mGoToLine, &KPIMTextEdit::TextGoToLineWidget::moveToLine, this, &SieveEditorTextModeWidget::slotGoToLine);
@@ -112,14 +122,14 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     connect(mFindBar, &KPIMTextEdit::TextEditFindBarBase::hideFindBar, mSliderContainer, &KPIMTextEdit::SlideContainer::slideOut);
     connect(mFindBar, &KPIMTextEdit::TextEditFindBarBase::displayMessageIndicator, mTextEdit, &KPIMTextEdit::PlainTextEditor::slotDisplayMessageIndicator);
     mSliderContainer->setContent(mFindBar);
-    textEditLayout->addWidget(mSliderContainer);
+    editorWidgetLayout->addWidget(mSliderContainer);
 
     mSieveEditorWarning = new SieveEditorWarning;
-    textEditLayout->addWidget(mSieveEditorWarning);
+    editorWidgetLayout->addWidget(mSieveEditorWarning);
 
     mSieveParsingWarning = new SieveEditorParsingMissingFeatureWarning(SieveEditorParsingMissingFeatureWarning::TextEditor);
     connect(mSieveParsingWarning, &SieveEditorParsingMissingFeatureWarning::switchToGraphicalMode, this, &SieveEditorTextModeWidget::switchToGraphicalMode);
-    textEditLayout->addWidget(mSieveParsingWarning);
+    editorWidgetLayout->addWidget(mSieveParsingWarning);
 
     textEditWidget->setLayout(textEditLayout);
 
@@ -131,14 +141,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     connect(mSieveTemplateWidget, &SieveTemplateWidget::insertTemplate, mTextEdit, &SieveTextEdit::insertPlainText);
 
     //
-    QShortcut *shortcut = new QShortcut(this);
-    shortcut->setKey(Qt::Key_F + Qt::CTRL);
-    connect(shortcut, &QShortcut::activated, this, &SieveEditorTextModeWidget::slotFind);
     connect(mTextEdit, &SieveTextEdit::findText, this, &SieveEditorTextModeWidget::slotFind);
-
-    shortcut = new QShortcut(this);
-    shortcut->setKey(Qt::Key_R + Qt::CTRL);
-    connect(shortcut, &QShortcut::activated, this, &SieveEditorTextModeWidget::slotReplace);
     connect(mTextEdit, &SieveTextEdit::replaceText, this, &SieveEditorTextModeWidget::slotReplace);
 
     mDebugTextEdit = new KPIMTextEdit::PlainTextEditorWidget;
@@ -223,7 +226,7 @@ void SieveEditorTextModeWidget::generateXml()
 #endif
 }
 
-void SieveEditorTextModeWidget::autoGenerateScripts()
+void SieveEditorTextModeWidget::createRulesGraphically()
 {
     QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
     dlg->setSieveCapabilities(mSieveCapabilities);
@@ -251,53 +254,89 @@ void SieveEditorTextModeWidget::replace()
 
 void SieveEditorTextModeWidget::undo()
 {
-    mTextEdit->undo();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->undo();
+    }
 }
 
 void SieveEditorTextModeWidget::redo()
 {
-    mTextEdit->redo();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->redo();
+    }
 }
 
 void SieveEditorTextModeWidget::paste()
 {
-    mTextEdit->paste();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->paste();
+    }
 }
 
 void SieveEditorTextModeWidget::cut()
 {
-    mTextEdit->cut();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->cut();
+    }
 }
 
 void SieveEditorTextModeWidget::copy()
 {
-    mTextEdit->copy();
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->copy();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        page->copy();
+    }
 }
 
 void SieveEditorTextModeWidget::selectAll()
 {
-    mTextEdit->selectAll();
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->selectAll();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        page->selectAll();
+    }
 }
 
 bool SieveEditorTextModeWidget::isUndoAvailable() const
 {
-    return mTextEdit->document()->isUndoAvailable();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        return mTextEdit->document()->isUndoAvailable();
+    }
+    return false;
 }
 
 bool SieveEditorTextModeWidget::isRedoAvailable() const
 {
-    return mTextEdit->document()->isRedoAvailable();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        return mTextEdit->document()->isRedoAvailable();
+    }
+    return false;
 }
 
 bool SieveEditorTextModeWidget::hasSelection() const
 {
-    return mTextEdit->textCursor().hasSelection();
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        return mTextEdit->textCursor().hasSelection();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        return page->hasSelection();
+    }
+    return false;
 }
 
 void SieveEditorTextModeWidget::zoomIn()
 {
-    QWidget *w = mTabWidget->currentWidget();
-    if (w == mTextEdit) {
+   QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
         mTextEdit->zoomIn();
     } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomIn();
@@ -307,7 +346,7 @@ void SieveEditorTextModeWidget::zoomIn()
 void SieveEditorTextModeWidget::zoomOut()
 {
     QWidget *w = mTabWidget->currentWidget();
-    if (w == mTextEdit) {
+    if (w == mEditorWidget) {
         mTextEdit->zoomOut();
     } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomOut();
@@ -319,6 +358,33 @@ bool SieveEditorTextModeWidget::isWordWrap() const
     return mTextEdit->isWordWrap();
 }
 
+void SieveEditorTextModeWidget::print()
+{
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        QPrinter printer;
+
+        QScopedPointer<QPrintDialog> dlg(new QPrintDialog(&printer));
+
+        if (dlg && dlg->exec() == QDialog::Accepted) {
+            mTextEdit->print(&printer);
+        }
+    }
+}
+
+void SieveEditorTextModeWidget::printPreview()
+{
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+
+        PimCommon::KPimPrintPreviewDialog previewdlg(this);
+        connect(&previewdlg, &QPrintPreviewDialog::paintRequested, this, [this](QPrinter * printer) {
+            mTextEdit->print(printer);
+        });
+        previewdlg.exec();
+    }
+}
+
 void SieveEditorTextModeWidget::wordWrap(bool state)
 {
     mTextEdit->wordWrap(state);
@@ -327,7 +393,7 @@ void SieveEditorTextModeWidget::wordWrap(bool state)
 void SieveEditorTextModeWidget::zoomReset()
 {
     QWidget *w = mTabWidget->currentWidget();
-    if (w == mTextEdit) {
+    if (w == mEditorWidget) {
         mTextEdit->slotZoomReset();
     } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->resetZoom();
@@ -481,3 +547,14 @@ void SieveEditorTextModeWidget::debugSieveScript()
     }
     delete dlg;
 }
+
+bool SieveEditorTextModeWidget::isTextEditor() const
+{
+    const QWidget *w = mTabWidget->currentWidget();
+    return (w == mEditorWidget);
+}
+
+bool SieveEditorTextModeWidget::printSupportEnabled() const
+{
+    return isTextEditor();
+}
