@@ -66,13 +66,13 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
     connect(mCheckSyntax, &QAction::triggered, this, &SieveEditorWidget::slotCheckSyntax);
     toolbar->addAction(mCheckSyntax);
-    mSaveAs = KStandardAction::saveAs(this, SLOT(slotSaveAs()), this);
+    mSaveAs = KStandardAction::saveAs(this, &SieveEditorWidget::slotSaveAs, this);
     toolbar->addAction(mSaveAs);
     toolbar->addAction(i18n("Import..."), this, SLOT(slotImport()));
 
-    mAutoGenerateScript = new QAction(i18n("Autogenerate Script..."), this);
-    connect(mAutoGenerateScript, &QAction::triggered, this, &SieveEditorWidget::slotAutoGenerateScripts);
-    toolbar->addAction(mAutoGenerateScript);
+    mCreateRulesGraphically = new QAction(i18n("Create Rules Graphically..."), this);
+    connect(mCreateRulesGraphically, &QAction::triggered, this, &SieveEditorWidget::slotCreateRulesGraphically);
+    toolbar->addAction(mCreateRulesGraphically);
     mSwitchMode = new QAction(this);
     toolbar->addAction(mSwitchMode);
     connect(mSwitchMode, &QAction::triggered, this, &SieveEditorWidget::slotSwitchMode);
@@ -87,12 +87,11 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 
     QStringList overlays;
     overlays << QStringLiteral("list-add");
-    mUpload = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share..."), this);
-    connect(mUpload, &QAction::triggered, this, &SieveEditorWidget::slotUploadScripts);
-    connect(mUpload, &QAction::triggered, this, &SieveEditorWidget::slotUploadScripts);
+    mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share..."), this);
+    connect(mShareScript, &QAction::triggered, this, &SieveEditorWidget::slotShareScript);
     //Add action to toolBar
 
-    toolbar->addAction(mUpload);
+    toolbar->addAction(mShareScript);
 
     if (useMenuBar) {
         SieveEditorMenuBar *menuBar = new SieveEditorMenuBar;
@@ -113,15 +112,17 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         connect(menuBar, &SieveEditorMenuBar::zoomReset, this, &SieveEditorWidget::zoomReset);
         connect(menuBar, &SieveEditorMenuBar::debugSieveScript, this, &SieveEditorWidget::debugSieveScript);
         connect(menuBar, &SieveEditorMenuBar::wordWrap, this, &SieveEditorWidget::wordWrap);
+        connect(menuBar, &SieveEditorMenuBar::print, this, &SieveEditorWidget::print);
+        connect(menuBar, &SieveEditorMenuBar::printPreview, this, &SieveEditorWidget::printPreview);
 
         connect(this, &SieveEditorWidget::copyAvailable, menuBar, &SieveEditorMenuBar::slotCopyAvailable);
         connect(this, &SieveEditorWidget::redoAvailable, menuBar, &SieveEditorMenuBar::slotRedoAvailable);
         connect(this, &SieveEditorWidget::undoAvailable, menuBar, &SieveEditorMenuBar::slotUndoAvailable);
         menuBar->fileMenu()->addAction(mSaveAs);
         menuBar->fileMenu()->addSeparator();
-        menuBar->fileMenu()->addAction(mUpload);
+        menuBar->fileMenu()->addAction(mShareScript);
         menuBar->toolsMenu()->addSeparator();
-        menuBar->toolsMenu()->addAction(mAutoGenerateScript);
+        menuBar->toolsMenu()->addAction(mCreateRulesGraphically);
         menuBar->toolsMenu()->addAction(mCheckSyntax);
         lay->addWidget(menuBar);
     }
@@ -155,6 +156,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     connect(mTextModeWidget, &SieveEditorTextModeWidget::undoAvailable, this, &SieveEditorWidget::undoAvailable);
     connect(mTextModeWidget, &SieveEditorTextModeWidget::redoAvailable, this, &SieveEditorWidget::redoAvailable);
     connect(mTextModeWidget, &SieveEditorTextModeWidget::copyAvailable, this, &SieveEditorWidget::copyAvailable);
+    connect(mTextModeWidget, &SieveEditorTextModeWidget::sieveEditorTabCurrentChanged, this, &SieveEditorWidget::sieveEditorTabCurrentChanged);
     if (KSieveUi::EditorSettings::useGraphicEditorByDefault()) {
         changeMode(GraphicMode);
     } else {
@@ -240,6 +242,40 @@ bool SieveEditorWidget::isWordWrap() const
     return false;
 }
 
+void SieveEditorWidget::updateOriginalScript()
+{
+    mOriginalScript = script();
+}
+
+void SieveEditorWidget::print()
+{
+    switch (mMode) {
+    case TextMode:
+        mTextModeWidget->print();
+        break;
+    case GraphicMode:
+        break;
+    case Unknown:
+        qCDebug(LIBKSIEVE_LOG) << " Unknown mode";
+        break;
+    }
+
+}
+
+void SieveEditorWidget::printPreview()
+{
+    switch (mMode) {
+    case TextMode:
+        mTextModeWidget->printPreview();
+        break;
+    case GraphicMode:
+        break;
+    case Unknown:
+        qCDebug(LIBKSIEVE_LOG) << " Unknown mode";
+        break;
+    }
+}
+
 void SieveEditorWidget::wordWrap(bool state)
 {
     if (mMode == TextMode) {
@@ -333,7 +369,7 @@ void SieveEditorWidget::setModified(bool b)
     }
 }
 
-void SieveEditorWidget::slotUploadScripts()
+void SieveEditorWidget::slotShareScript()
 {
     QTemporaryDir tmp;
     QTemporaryFile tmpFile;
@@ -368,7 +404,7 @@ void SieveEditorWidget::changeMode(EditorMode mode)
         mMode = mode;
         mStackedWidget->setCurrentIndex(static_cast<int>(mode));
         const bool isTextMode = (mMode == TextMode);
-        mAutoGenerateScript->setEnabled(isTextMode);
+        mCreateRulesGraphically->setEnabled(isTextMode);
 #if !defined(NDEBUG)
         if (mGenerateXml) {
             mGenerateXml->setEnabled(isTextMode);
@@ -439,6 +475,11 @@ void SieveEditorWidget::addOkMessage(const QString &msg)
     addMessageEntry(msg, QColor(Qt::darkGreen));
 }
 
+void SieveEditorWidget::addNormalMessage(const QString &msg)
+{
+    addMessageEntry(msg, palette().color(QPalette::WindowText));
+}
+
 void SieveEditorWidget::addMessageEntry(const QString &errorMsg, const QColor &color)
 {
     QString msg = errorMsg;
@@ -470,11 +511,11 @@ void SieveEditorWidget::setSieveCapabilities(const QStringList &capabilities)
     mGraphicalModeWidget->setSieveCapabilities(capabilities);
 }
 
-void SieveEditorWidget::slotAutoGenerateScripts()
+void SieveEditorWidget::slotCreateRulesGraphically()
 {
     switch (mMode) {
     case TextMode:
-        mTextModeWidget->autoGenerateScripts();
+        mTextModeWidget->createRulesGraphically();
         break;
     case GraphicMode:
     case Unknown:
@@ -654,3 +695,19 @@ QUrl SieveEditorWidget::currentHelpUrl() const
     }
     return QUrl();
 }
+
+bool SieveEditorWidget::isTextEditor() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->isTextEditor();
+    }
+    return false;
+}
+
+bool SieveEditorWidget::printSupportEnabled() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->printSupportEnabled();
+    }
+    return false;
+}
