@@ -1,18 +1,20 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef VACATIONSCRIPTEXTRACTOR_H
@@ -681,42 +683,42 @@ public:
     }
 
 private:
-    void commandStart(const QString &identifier, int lineNumber);
+    void commandStart(const QString &identifier, int lineNumber) Q_DECL_OVERRIDE;
 
-    void commandEnd(int lineNumber);
+    void commandEnd(int lineNumber) Q_DECL_OVERRIDE;
 
-    void testStart(const QString &) {}
-    void testEnd() {}
-    void testListStart() {}
-    void testListEnd() {}
-    void blockStart(int lineNumber)
+    void testStart(const QString &) Q_DECL_OVERRIDE {}
+    void testEnd() Q_DECL_OVERRIDE {}
+    void testListStart() Q_DECL_OVERRIDE {}
+    void testListEnd() Q_DECL_OVERRIDE {}
+    void blockStart(int lineNumber) Q_DECL_OVERRIDE
     {
         Q_UNUSED(lineNumber)
     }
-    void blockEnd(int lineNumber)
+    void blockEnd(int lineNumber) Q_DECL_OVERRIDE
     {
         Q_UNUSED(lineNumber)
     }
-    void hashComment(const QString &) {}
-    void bracketComment(const QString &) {}
-    void lineFeed() {}
-    void error(const KSieve::Error &e);
-    void finished();
+    void hashComment(const QString &) Q_DECL_OVERRIDE {}
+    void bracketComment(const QString &) Q_DECL_OVERRIDE {}
+    void lineFeed() Q_DECL_OVERRIDE {}
+    void error(const KSieve::Error &e) Q_DECL_OVERRIDE;
+    void finished() Q_DECL_OVERRIDE;
 
-    void taggedArgument(const QString &tag)
+    void taggedArgument(const QString &tag) Q_DECL_OVERRIDE
     {
         Q_UNUSED(tag)
     }
-    void numberArgument(unsigned long number, char)
+    void numberArgument(unsigned long number, char) Q_DECL_OVERRIDE
     {
         Q_UNUSED(number)
     }
 
-    void stringArgument(const QString &string, bool, const QString &);
+    void stringArgument(const QString &string, bool, const QString &) Q_DECL_OVERRIDE;
 
-    void stringListArgumentStart() {}
-    void stringListEntry(const QString &string, bool, const QString &);
-    void stringListArgumentEnd() {}
+    void stringListArgumentStart() Q_DECL_OVERRIDE {}
+    void stringListEntry(const QString &string, bool, const QString &) Q_DECL_OVERRIDE;
+    void stringListArgumentEnd() Q_DECL_OVERRIDE {}
 
 private:
     Context mContext;
